nvector._core.lat_lon2n_E — nvector 0.7.5 documentation

# nvector._core.lat_lon2n_E

`lat_lon2n_E`(latitude, longitude, R_Ee=None)

  Converts latitude and longitude to n-vector.

  Parameters
    latitude, longitude: real scalars or vectors of length n.

      Geodetic latitude and longitude given in [rad]

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    n_E: 3 x n array

      n-vector(s) [no unit] decomposed in E.

  See also

  `n_E2lat_lon`